@@ -3,7 +3,7 @@ use crate::{
   objects::{person::ApubPerson, private_message::ApubPrivateMessage},
   protocol::activities::private_message::delete::DeletePrivateMessage,
 };
-use activitystreams::activity::kind::DeleteType;
+use activitystreams_kinds::activity::DeleteType;
 use lemmy_api_common::blocking;
 use lemmy_apub_lib::{
   data::Data,
@@ -36,6 +36,8 @@ impl DeletePrivateMessage {
       unparsed: Default::default(),
     })
   }
+
+  #[tracing::instrument(skip_all)]
   pub async fn send(
     actor: &ApubPerson,
     pm: &ApubPrivateMessage,
@@ -57,6 +59,8 @@ impl DeletePrivateMessage {
 #[async_trait::async_trait(?Send)]
 impl ActivityHandler for DeletePrivateMessage {
   type DataType = LemmyContext;
+
+  #[tracing::instrument(skip_all)]
   async fn verify(
     &self,
     context: &Data<LemmyContext>,
@@ -68,6 +72,7 @@ impl ActivityHandler for DeletePrivateMessage {
     Ok(())
   }
 
+  #[tracing::instrument(skip_all)]
   async fn receive(
     self,
     context: &Data<LemmyContext>,
