@@ -17,12 +17,15 @@ mod tests {
   async fn test_parse_lemmy_private_message() {
     test_parse_lemmy_item::<CreateOrUpdatePrivateMessage>(
       "assets/lemmy/activities/private_message/create.json",
-    );
+    )
+    .unwrap();
     test_parse_lemmy_item::<DeletePrivateMessage>(
       "assets/lemmy/activities/private_message/delete.json",
-    );
+    )
+    .unwrap();
     test_parse_lemmy_item::<UndoDeletePrivateMessage>(
       "assets/lemmy/activities/private_message/undo_delete.json",
-    );
+    )
+    .unwrap();
   }
 }
